@@ -37,7 +37,7 @@
 #  include <config.h>
 #endif
 
-#define _XOPEN_SOURCE /* glibc2 needs this (man strptime) */
+#define _XOPEN_SOURCE	600 /* glibc2 needs this (man strptime) */
 
 #include <libxml/uri.h>
 
@@ -251,8 +251,11 @@ time_t parseISO8601Date(gchar *date) {
 	if(TRUE == success) {
 		if((time_t)(-1) != (t = mktime(&tm))) {
 			/* Correct for the local timezone*/
+			struct tm tmp_tm;
+			
 			t = t - offset;
-			t2 = mktime(gmtime(&t));
+			gmtime_r(&t, &tmp_tm);
+			t2 = mktime(&tmp_tm);
 			t = t - (t2 - t);
 			
 			return t;
@@ -406,6 +409,9 @@ static void common_init_cache_path(void) {
 
 	g_free(cachePath);
 	/* lifereaUserPath reused globally */
+	
+	/* ensure reasonable default umask */
+	umask (077);
 }
 
 const gchar * common_get_cache_path(void) {
